@@ -64,7 +64,7 @@ class pulsar_qcm_qcodes(pulsar_qcm_ifc, Instrument):
         Instrument.__init__(self, name)
 
         #Set instrument parameters
-        self._num_sequencers = 2
+        self._num_sequencers = 6
 
         #Set JSON schema to validate JSON file with
         self._wave_and_prog_json_schema = {"title":       "Sequencer waveforms and program container",
@@ -112,9 +112,9 @@ class pulsar_qcm_qcodes(pulsar_qcm_ifc, Instrument):
 
         if self._get_lo_hw_present():
             self.add_parameter(
-                "lo0_freq",
-                label      = "Local Oscillator 0 frequency.",
-                docstring  = "Sets/gets the local oscillator 0 output frequency.",
+                "out0_lo_freq",
+                label      = "Local Oscillator frequency for output 0.",
+                docstring  = "Sets/gets the local oscillator frequency for output 0.",
                 unit       = 'Hz',
                 vals       = vals.Numbers(2e9, 18e9),
                 set_parser = int,
@@ -124,9 +124,9 @@ class pulsar_qcm_qcodes(pulsar_qcm_ifc, Instrument):
             )
 
             self.add_parameter(
-                "lo1_freq",
-                label      = "Local Oscillator 1 frequency.",
-                docstring  = "Sets/gets the local oscillator 1 output frequency.",
+                "out1_lo_freq",
+                label      = "Local Oscillator frequency for output 1.",
+                docstring  = "Sets/gets the local oscillator frequency for output 1.",
                 unit       = 'Hz',
                 vals       = vals.Numbers(2e9, 18e9),
                 set_parser = int,
@@ -135,8 +135,153 @@ class pulsar_qcm_qcodes(pulsar_qcm_ifc, Instrument):
                 get_cmd    = self._get_lo_freq_1
             )
 
+        if self._get_lo_hw_present():
+            self.add_parameter(
+                "out0_offset_path0",
+                label      = "Output 0 offset for path 0.",
+                docstring  = "Sets/gets output 0 offset for path 0.",
+                unit       = 'mV',
+                vals       = vals.Numbers(-84.0, 73.0),
+                set_parser = float,
+                get_parser = float,
+                set_cmd    = self._set_out_amp_offset_0,
+                get_cmd    = self._get_out_amp_offset_0
+            )
+
+            self.add_parameter(
+                "out0_offset_path1",
+                label      = "Output 0 offset for path 1.",
+                docstring  = "Sets/gets output 0 offset for path 1.",
+                unit       = 'mV',
+                vals       = vals.Numbers(-84.0, 73.0),
+                set_parser = float,
+                get_parser = float,
+                set_cmd    = self._set_out_amp_offset_1,
+                get_cmd    = self._get_out_amp_offset_1
+            )
+
+            self.add_parameter(
+                "out1_offset_path0",
+                label      = "Output 1 offset for path 0.",
+                docstring  = "Sets/gets output 1 offset for path 0.",
+                unit       = 'mV',
+                vals       = vals.Numbers(-84.0, 73.0),
+                set_parser = float,
+                get_parser = float,
+                set_cmd    = self._set_out_amp_offset_2,
+                get_cmd    = self._get_out_amp_offset_2
+            )
+
+            self.add_parameter(
+                "out1_offset_path1",
+                label      = "Output 1 offset for path 1.",
+                docstring  = "Sets/gets output 1 offset for path 1.",
+                unit       = 'mV',
+                vals       = vals.Numbers(-84.0, 73.0),
+                set_parser = float,
+                get_parser = float,
+                set_cmd    = self._set_out_amp_offset_3,
+                get_cmd    = self._get_out_amp_offset_3
+            )
+        else:
+            self.add_parameter(
+                "out0_offset",
+                label      = "Output 0 offset.",
+                docstring  = "Sets/gets output 0 offset.",
+                unit       = 'V',
+                vals       = vals.Numbers(-2.5, 2.5),
+                set_parser = float,
+                get_parser = float,
+                set_cmd    = self._set_dac_offset_0,
+                get_cmd    = self._get_dac_offset_0
+            )
+
+            self.add_parameter(
+                "out1_offset",
+                label      = "Output 1 offset.",
+                docstring  = "Sets/gets output 1 offset.",
+                unit       = 'V',
+                vals       = vals.Numbers(-2.5, 2.5),
+                set_parser = float,
+                get_parser = float,
+                set_cmd    = self._set_dac_offset_1,
+                get_cmd    = self._get_dac_offset_1
+            )
+
+            self.add_parameter(
+                "out2_offset",
+                label      = "Output 2 offset.",
+                docstring  = "Sets/gets output 2 offset.",
+                unit       = 'V',
+                vals       = vals.Numbers(-2.5, 2.5),
+                set_parser = float,
+                get_parser = float,
+                set_cmd    = self._set_dac_offset_2,
+                get_cmd    = self._get_dac_offset_2
+            )
+
+            self.add_parameter(
+                "out3_offset",
+                label      = "Output 3 offset.",
+                docstring  = "Sets/gets output 3 offset.",
+                unit       = 'V',
+                vals       = vals.Numbers(-2.5, 2.5),
+                set_parser = float,
+                get_parser = float,
+                set_cmd    = self._set_dac_offset_3,
+                get_cmd    = self._get_dac_offset_3
+            )
+
         for seq_idx in range(0, self._num_sequencers):
             #--Sequencer settings----------------------------------------------
+            self.add_parameter(
+                "sequencer{}_channel_map_path0_out0_en".format(seq_idx),
+                label      = "Sequencer {} path 0 output 0 enable.".format(seq_idx),
+                docstring  = "Sets/gets sequencer {} channel map enable of path 0 to output 0.".format(seq_idx),
+                unit       = '',
+                vals       = vals.Bool(),
+                set_parser = bool,
+                get_parser = bool,
+                set_cmd    = partial(self._set_sequencer_channel_map, seq_idx, 0),
+                get_cmd    = partial(self._get_sequencer_channel_map, seq_idx, 0)
+            )
+
+            self.add_parameter(
+                "sequencer{}_channel_map_path1_out1_en".format(seq_idx),
+                label      = "Sequencer {} path 1 output 1 enable.".format(seq_idx),
+                docstring  = "Sets/gets sequencer {} channel map enable of path 1 to output 1.".format(seq_idx),
+                unit       = '',
+                vals       = vals.Bool(),
+                set_parser = bool,
+                get_parser = bool,
+                set_cmd    = partial(self._set_sequencer_channel_map, seq_idx, 1),
+                get_cmd    = partial(self._get_sequencer_channel_map, seq_idx, 1)
+            )
+
+            self.add_parameter(
+                "sequencer{}_channel_map_path0_out2_en".format(seq_idx),
+                label      = "Sequencer {} path 0 output 2 enable.".format(seq_idx),
+                docstring  = "Sets/gets sequencer {} channel map enable of path 0 to output 2.".format(seq_idx),
+                unit       = '',
+                vals       = vals.Bool(),
+                set_parser = bool,
+                get_parser = bool,
+                set_cmd    = partial(self._set_sequencer_channel_map, seq_idx, 2),
+                get_cmd    = partial(self._get_sequencer_channel_map, seq_idx, 2)
+            )
+
+            self.add_parameter(
+                "sequencer{}_channel_map_path1_out3_en".format(seq_idx),
+                label      = "Sequencer {} path 1 output 3 enable.".format(seq_idx),
+                docstring  = "Sets/gets sequencer {} channel map enable of path 1 to output 3.".format(seq_idx),
+                unit       = '',
+                vals       = vals.Bool(),
+                set_parser = bool,
+                get_parser = bool,
+                set_cmd    = partial(self._set_sequencer_channel_map, seq_idx, 3),
+                get_cmd    = partial(self._get_sequencer_channel_map, seq_idx, 3)
+            )
+
             self.add_parameter(
                 "sequencer{}_sync_en".format(seq_idx),
                 label      = "Sequencer {} synchronization enable which enables party-line synchronization.".format(seq_idx),
@@ -330,6 +475,30 @@ class pulsar_qcm_qcodes(pulsar_qcm_ifc, Instrument):
                 get_cmd    = partial(self._get_sequencer_config_val, seq_idx, "offset_awg_path_1_float")
             )
 
+            self.add_parameter(
+                "sequencer{}_mixer_corr_phase_offset_degree".format(seq_idx),
+                label      = "Sequencer {} mixer phase imbalance correction for AWG; applied to AWG path 1 relative to AWG path 0 and measured in degrees.".format(seq_idx),
+                docstring  = "Sets/gets sequencer {} mixer phase imbalance correction for AWG; applied to AWG path 1 relative to AWG path 0 and measured in degrees".format(seq_idx),
+                unit       = '',
+                vals       = vals.Numbers(-45.0, 45.0),
+                set_parser = float,
+                get_parser = float,
+                set_cmd    = partial(self._set_sequencer_config_val, seq_idx, "mixer_corr_phase_offset_degree_float"),
+                get_cmd    = partial(self._get_sequencer_config_val, seq_idx, "mixer_corr_phase_offset_degree_float")
+            )
+
+            self.add_parameter(
+                "sequencer{}_mixer_corr_gain_ratio".format(seq_idx),
+                label      = "Sequencer {} mixer gain imbalance correction for AWG; equal to AWG path 1 amplitude divided by AWG path 0 amplitude.".format(seq_idx),
+                docstring  = "Sets/gets sequencer {} mixer gain imbalance correction for AWG; equal to AWG path 1 amplitude divided by AWG path 0 amplitude.".format(seq_idx),
+                unit       = '',
+                vals       = vals.Numbers(0.5, 2.0),
+                set_parser = float,
+                get_parser = float,
+                set_cmd    = partial(self._set_sequencer_config_val, seq_idx, "mixer_corr_gain_ratio_float"),
+                get_cmd    = partial(self._get_sequencer_config_val, seq_idx, "mixer_corr_gain_ratio_float")
+            )
+
             self.add_parameter(
                 "sequencer{}_mod_en_awg".format(seq_idx),
                 label      = "Sequencer {} modulation enable for AWG.".format(seq_idx),
