@@ -336,8 +336,8 @@ class pulsar_qrm_ifc(pulsar_qrm_scpi_ifc):
         """
 
         seq_proc_cfg_format  = '?I'
-        awg_cfg_format       = '??IIIIIIIIIII?III??I'
-        awg_float_cfg_format = 'fdffff'
+        awg_cfg_format       = '??IIIIIIIIIII?IIIIIII??I'
+        awg_float_cfg_format = 'fdffffff'
         acq_cfg_format       = 'II?IIIq'
         acq_float_cfg_format = 'ffd'
 
@@ -374,52 +374,59 @@ class pulsar_qrm_ifc(pulsar_qrm_scpi_ifc):
 
             #Set new configuration
             cfg = [#Sequence processor
-                   cfg_dict["sync_en"],                           #Sequence processor synchronization enable
-                   0,                                             #Sequence processor program counter start (unused)
+                   cfg_dict["sync_en"],                                 #Sequence processor synchronization enable
+                   0,                                                   #Sequence processor program counter start (unused)
 
                    #AWG
-                   cfg_dict["cont_mode_en_awg_path_0"],           #Continuous mode enable for AWG path 0
-                   cfg_dict["cont_mode_en_awg_path_1"],           #Continuous mode enable for AWG path 1
-                   cfg_dict["cont_mode_waveform_idx_awg_path_0"], #continuous mode waveform index for AWG path 0
-                   cfg_dict["cont_mode_waveform_idx_awg_path_1"], #Continuous mode waveform index for AWG path 1
-                   cfg_dict["upsample_rate_awg_path_0"],          #Upsample rate for AWG path 0
-                   cfg_dict["upsample_rate_awg_path_1"],          #Upsample rate for AWG path 1
-                   0,                                             #Gain for AWG path 0         (unused)
-                   0,                                             #Gain for AWG path 1         (unused)
-                   0,                                             #Offset for AWG path 0       (unused)
-                   0,                                             #Offset for AWG path 1       (unused)
-                   0,                                             #Phase increment; ultra-fine (unused)
-                   0,                                             #Phase increment; fine       (unused)
-                   0,                                             #Phase increment; coarse     (unused)
-                   0,                                             #Phase increment; sign       (unused)
-                   0,                                             #Phase; ultra-fine           (unused)
-                   0,                                             #Phase; fine                 (unused)
-                   0,                                             #Phase; coarse               (unused)
-                   cfg_dict["mod_en_awg"],                        #Modulation enable for AWG paths 0 and 1
-                   cfg_dict["mrk_ovr_en"],                        #Marker override enable
-                   cfg_dict["mrk_ovr_val"],                       #Marker override value
+                   cfg_dict["cont_mode_en_awg_path_0"],                 #Continuous mode enable for AWG path 0
+                   cfg_dict["cont_mode_en_awg_path_1"],                 #Continuous mode enable for AWG path 1
+                   cfg_dict["cont_mode_waveform_idx_awg_path_0"],       #continuous mode waveform index for AWG path 0
+                   cfg_dict["cont_mode_waveform_idx_awg_path_1"],       #Continuous mode waveform index for AWG path 1
+                   cfg_dict["upsample_rate_awg_path_0"],                #Upsample rate for AWG path 0
+                   cfg_dict["upsample_rate_awg_path_1"],                #Upsample rate for AWG path 1
+                   0,                                                   #Gain for AWG path 0         (unused)
+                   0,                                                   #Gain for AWG path 1         (unused)
+                   0,                                                   #Offset for AWG path 0       (unused)
+                   0,                                                   #Offset for AWG path 1       (unused)
+                   0,                                                   #Phase increment; ultra-fine (unused)
+                   0,                                                   #Phase increment; fine       (unused)
+                   0,                                                   #Phase increment; coarse     (unused)
+                   0,                                                   #Phase increment; sign       (unused)
+                   0,                                                   #Phase; ultra-fine           (unused)
+                   0,                                                   #Phase; fine                 (unused)
+                   0,                                                   #Phase; coarse               (unused)
+                   0,                                                   #Mixer correction matrix a11 (unsued)
+                   0,                                                   #Mixer correction matrix a12 (unsued)
+                   0,                                                   #Mixer correction matrix a21 (unsued)
+                   0,                                                   #Mixer correction matrix a22 (unsued)
+                   cfg_dict["mod_en_awg"],                              #Modulation enable for AWG paths 0 and 1
+                   cfg_dict["mrk_ovr_en"],                              #Marker override enable
+                   cfg_dict["mrk_ovr_val"],                             #Marker override value
+
 
                    #AWG floating point values to be converted
-                   cfg_dict["phase_offs_degree"],                 #Phase offset in degrees
-                   cfg_dict["freq_hz"],                           #Frequency in Hz
-                   cfg_dict["gain_awg_path_0_float"],             #Gain for AWG path 0 as float
-                   cfg_dict["gain_awg_path_1_float"],             #Gain for AWG path 1 as float
-                   cfg_dict["offset_awg_path_0_float"],           #Offset for AWG path 0 as float
-                   cfg_dict["offset_awg_path_1_float"],           #Offset for AWG path 1 as float
+                   cfg_dict["phase_offs_degree"],                       #Phase offset in degrees
+                   cfg_dict["freq_hz"],                                 #Frequency in Hz
+                   cfg_dict["gain_awg_path_0_float"],                   #Gain for AWG path 0 as float
+                   cfg_dict["gain_awg_path_1_float"],                   #Gain for AWG path 1 as float
+                   cfg_dict["offset_awg_path_0_float"],                 #Offset for AWG path 0 as float
+                   cfg_dict["offset_awg_path_1_float"],                 #Offset for AWG path 1 as float
+                   cfg_dict["mixer_corr_phase_offset_degree_float"],    #NCO compensation for mixer: phase offset
+                   cfg_dict["mixer_corr_gain_ratio_float"],             #NCO compensation for mixer: gain imbalance
 
                    #Acquisition
-                   cfg_dict["upsample_rate_acq_path_0"],          #Upsample rate for acquisition path 0
-                   cfg_dict["upsample_rate_acq_path_1"],          #Upsample rate for acquisition path 1
-                   cfg_dict["demod_en_acq"],                      #Demodulation enable
-	               cfg_dict["non_weighed_integration_len"],       #Non weighed integration length
-	               0,                                             #Rotation matrix A11 (unused)
-	               0,                                             #Rotation matrix A12 (unused)
-	               0,                                             #Discretization threshold (unused)
+                   cfg_dict["upsample_rate_acq_path_0"],                #Upsample rate for acquisition path 0
+                   cfg_dict["upsample_rate_acq_path_1"],                #Upsample rate for acquisition path 1
+                   cfg_dict["demod_en_acq"],                            #Demodulation enable
+	               cfg_dict["non_weighed_integration_len"],             #Non weighed integration length
+	               0,                                                   #Rotation matrix A11 (unused)
+	               0,                                                   #Rotation matrix A12 (unused)
+	               0,                                                   #Discretization threshold (unused)
 
                    #Acquisition floating point values to be converted
-                   cfg_dict["rotation_matrix_a11"],               #Rotation matrix A11
-                   cfg_dict["rotation_matrix_a12"],               #Rotation matrix A12
-                   cfg_dict["discr_threshold"]]                   #Discretization threshold
+                   cfg_dict["rotation_matrix_a11"],                     #Rotation matrix A11
+                   cfg_dict["rotation_matrix_a12"],                     #Rotation matrix A12
+                   cfg_dict["discr_threshold"]]                         #Discretization threshold
 
             super()._set_sequencer_config(sequencer, struct.pack(pulsar_qrm_ifc._get_sequencer_cfg_format(), *cfg))
         except:
@@ -453,37 +460,39 @@ class pulsar_qrm_ifc(pulsar_qrm_scpi_ifc):
         try:
             cfg      = struct.unpack(pulsar_qrm_ifc._get_sequencer_cfg_format(), super()._get_sequencer_config(sequencer))
             cfg_dict = {#Sequence processor
-                        "sync_en":                           cfg[0],
+                        "sync_en":                              cfg[0],
 
                         #AWG
-                        "cont_mode_en_awg_path_0":           cfg[2],
-                        "cont_mode_en_awg_path_1":           cfg[3],
-                        "cont_mode_waveform_idx_awg_path_0": cfg[4],
-                        "cont_mode_waveform_idx_awg_path_1": cfg[5],
-                        "upsample_rate_awg_path_0":          cfg[6],
-                        "upsample_rate_awg_path_1":          cfg[7],
-                        "mod_en_awg":                        cfg[19],
-                        "mrk_ovr_en":                        cfg[20],
-                        "mrk_ovr_val":                       cfg[21],
+                        "cont_mode_en_awg_path_0":              cfg[2],
+                        "cont_mode_en_awg_path_1":              cfg[3],
+                        "cont_mode_waveform_idx_awg_path_0":    cfg[4],
+                        "cont_mode_waveform_idx_awg_path_1":    cfg[5],
+                        "upsample_rate_awg_path_0":             cfg[6],
+                        "upsample_rate_awg_path_1":             cfg[7],
+                        "mod_en_awg":                           cfg[23],
+                        "mrk_ovr_en":                           cfg[24],
+                        "mrk_ovr_val":                          cfg[25],
 
                         #AWG floating point values
-                        "phase_offs_degree":                 cfg[22],
-                        "freq_hz":                           cfg[23],
-                        "gain_awg_path_0_float":             cfg[24],
-                        "gain_awg_path_1_float":             cfg[25],
-                        "offset_awg_path_0_float":           cfg[26],
-                        "offset_awg_path_1_float":           cfg[27],
+                        "phase_offs_degree":                    cfg[26],
+                        "freq_hz":                              cfg[27],
+                        "gain_awg_path_0_float":                cfg[28],
+                        "gain_awg_path_1_float":                cfg[29],
+                        "offset_awg_path_0_float":              cfg[30],
+                        "offset_awg_path_1_float":              cfg[31],
+                        "mixer_corr_phase_offset_degree_float": cfg[32],
+                        "mixer_corr_gain_ratio_float":          cfg[33],
 
                         #Acquisition
-                        "upsample_rate_acq_path_0":          cfg[28],
-                        "upsample_rate_acq_path_1":          cfg[29],
-                        "demod_en_acq":                      cfg[30],
-	                    "non_weighed_integration_len":       cfg[31],
-                        
+                        "upsample_rate_acq_path_0":             cfg[34],
+                        "upsample_rate_acq_path_1":             cfg[35],
+                        "demod_en_acq":                         cfg[36],
+	                    "non_weighed_integration_len":          cfg[37],
+
                         #Acquisition floating point values
-                        "rotation_matrix_a11":               cfg[35],
-                        "rotation_matrix_a12":               cfg[36],
-                        "discr_threshold":                   cfg[37]}
+                        "rotation_matrix_a11":                  cfg[41],
+                        "rotation_matrix_a12":                  cfg[42],
+                        "discr_threshold":                      cfg[43]}
             return cfg_dict
         except:
             raise
@@ -551,7 +560,79 @@ class pulsar_qrm_ifc(pulsar_qrm_scpi_ifc):
         except:
             raise
 
+    #---------------------------------------------------------------------------
+    def _set_sequencer_channel_map(self, sequencer, output, enable):
+        """
+        Set enable of the indexed sequencer's path to output.
+        If an invalid sequencer index is given or the channel map is not valid, an error is set in
+        system error.
 
+        Parameters
+        ----------
+        sequencer : int
+            Sequencer index.
+        output : int
+            output index.
+        enable : bool
+            Sequencer path to output enable
+
+        Returns
+        ----------
+
+        Raises
+        ----------
+        Exception
+            Invalid input parameter type.
+        Exception
+            An error is reported in system error and debug <= 1.
+            All errors are read from system error and listed in the exception.
+        """
+
+        try:
+            channel_map_bin = super()._get_sequencer_channel_map(sequencer)
+            channel_map     = list(struct.unpack("I"*int(len(channel_map_bin)/4),channel_map_bin))
+            if not output in channel_map and enable:
+                channel_map.append(output)
+            elif output in channel_map and not enable:
+                channel_map.remove(output)
+            super()._set_sequencer_channel_map(sequencer, struct.pack('I'*len(channel_map),*channel_map))
+        except:
+            raise
+
+    #---------------------------------------------------------------------------
+    def _get_sequencer_channel_map(self, sequencer, output):
+        """
+        Get enable of the indexed sequencer's path to output.
+        If an invalid sequencer index is given or the channel map is not valid, an error is set in
+        system error.
+
+        Parameters
+        ----------
+        sequencer : int
+            Sequencer index.
+        output : int
+            output index.
+
+        Returns
+        ----------
+        bytes
+            channel map list.
+
+        Raises
+        ----------
+        Exception
+            Invalid input parameter type.
+        Exception
+            An error is reported in system error and debug <= 1.
+            All errors are read from system error and listed in the exception.
+        """
+        try:
+            channel_map_bin = super()._get_sequencer_channel_map(sequencer)
+            channel_map     = list(struct.unpack("I"*int(len(channel_map_bin)/4),channel_map_bin))
+
+            return output in channel_map
+        except:
+            raise
 
     #--------------------------------------------------------------------------
     def arm_sequencer(self, sequencer=None):
@@ -710,7 +791,7 @@ class pulsar_qrm_ifc(pulsar_qrm_scpi_ifc):
                 - ACQ SCOPE OVERWRITTEN PATH 1: Scope acquisition data for path 1 was overwritten.
                 - ACQ BINNING DONE: Acquisition binning completed.
                 - ACQ BINNING FIFO ERROR: Acqusition binning encountered internal FIFO error.
-                - ACQ BINNING COMM ERROR: Acqusition binning encountered internal communication error. 
+                - ACQ BINNING COMM ERROR: Acqusition binning encountered internal communication error.
                 - ACQ BINNING OUT-OF-RANGE: Acquisition binning data out-of-range.
                 - ACQ INDEX INVALID: Acquisition tried to process an invalid acquisition.
                 - ACQ BIN INDEX INVALID: Acquisition tried to process an invalid bin.
@@ -957,7 +1038,7 @@ class pulsar_qrm_ifc(pulsar_qrm_scpi_ifc):
         """
         Add new acquisition to acquisition list of indexed sequencer's acquisition path. If an invalid sequencer index is given or if the required acquisition memory
         cannot be allocated, an error is set in system error. The acquisition names 'all' and 'ALL' are reserved and adding those will also result in an
-        error being set in system error. If no index is given, the next available weight index is selected (starting from 0). If an invalid weight index is given, an 
+        error being set in system error. If no index is given, the next available weight index is selected (starting from 0). If an invalid weight index is given, an
         error is set in system error.
 
         Parameters
@@ -1039,8 +1120,8 @@ class pulsar_qrm_ifc(pulsar_qrm_scpi_ifc):
         avg_cnt = acquisition_dict["scope"]["path0"]["avg_cnt"]
         acquisition_dict["scope"]["path0"]["data"] = [val / max_sample_value if avg_cnt == 0 else val / max_sample_value / avg_cnt for val in acquisition_dict["scope"]["path0"]["data"]]
         avg_cnt = acquisition_dict["scope"]["path1"]["avg_cnt"]
-        acquisition_dict["scope"]["path1"]["data"] = [val / max_sample_value if avg_cnt == 0 else val / max_sample_value / avg_cnt for val in acquisition_dict["scope"]["path1"]["data"]]    
-        
+        acquisition_dict["scope"]["path1"]["data"] = [val / max_sample_value if avg_cnt == 0 else val / max_sample_value / avg_cnt for val in acquisition_dict["scope"]["path1"]["data"]]
+
         #Retrieve bin data
         bins       = self._read_bin('', flush_line_end)
         bin_format = 'QqqLL'
@@ -1064,7 +1145,7 @@ class pulsar_qrm_ifc(pulsar_qrm_scpi_ifc):
                 thres     = float("NaN")
                 avg_cnt   = float("NaN")
 
-            acquisition_dict["bins"]["integration"]["path0"].append(bin_path0) 
+            acquisition_dict["bins"]["integration"]["path0"].append(bin_path0)
             acquisition_dict["bins"]["integration"]["path1"].append(bin_path1)
             acquisition_dict["bins"]["threshold"].append(thres)                                                               #Normalize
             acquisition_dict["bins"]["avg_cnt"].append(avg_cnt)
@@ -1076,7 +1157,7 @@ class pulsar_qrm_ifc(pulsar_qrm_scpi_ifc):
         """
         Get acquisition data of acquisition in acquisition list of indexed sequencer's acquisition path. The acquisition scope and bin data is normalized to a
         range of -1.0 to 1.0 taking both the bit widths of the processing path and average count into considaration. For the binned integration results, the integration
-        length is not handled during normalization and therefore these values have to be divided by their respective integration lenghts. If an invalid sequencer 
+        length is not handled during normalization and therefore these values have to be divided by their respective integration lenghts. If an invalid sequencer
         index is given or if a non-existing acquisition name is given, an error is set in system error.
 
         Parameters
@@ -1517,7 +1598,7 @@ class pulsar_qrm_ifc(pulsar_qrm_scpi_ifc):
     def store_scope_acquisition(self, sequencer, name):
         """
         After an acquisition has completed, store the scope acquisition results in the acquisition specified by name of the indexed sequencers. If an
-        invalid sequencer index is given an error is set in system error. To get access to the acquisition results, the sequencer will be stopped when calling 
+        invalid sequencer index is given an error is set in system error. To get access to the acquisition results, the sequencer will be stopped when calling
         this function.
 
         Parameters
@@ -1547,9 +1628,9 @@ class pulsar_qrm_ifc(pulsar_qrm_scpi_ifc):
     #--------------------------------------------------------------------------
     def get_acquisitions(self, sequencer):
         """
-        Get all acquisitions in acquisition lists of indexed sequencer. The acquisition scope and bin data is normalized to a range of -1.0 to 1.0 taking 
-        both the bit widths of the processing path and average count into considaration. For the binned integration results, the integration length is 
-        not handled during normalization and therefore these values have to be divided by their respective integration lenghts. The returned dictionary 
+        Get all acquisitions in acquisition lists of indexed sequencer. The acquisition scope and bin data is normalized to a range of -1.0 to 1.0 taking
+        both the bit widths of the processing path and average count into considaration. For the binned integration results, the integration length is
+        not handled during normalization and therefore these values have to be divided by their respective integration lenghts. The returned dictionary
         is structured as follows:
 
         - name: acquisition name
@@ -1570,14 +1651,14 @@ class pulsar_qrm_ifc(pulsar_qrm_scpi_ifc):
                         - data: acquisition samples in a range of 1.0 to -1.0.
                         - out-of-range: out-of-range indication for the entire acquisition (False = in-range, True = out-of-range).
                         - avg_cnt: number of averages.
-                
+
                 - bins: bin data
 
                     - integration: integration data
 
                         - path_0: input path 0 integration result bin list
                         - path_1: input path 1 integration result bin list
-                    
+
                     - threshold: threshold result bin list
                     - valid: list of valid indications per bin
                     - avg_cnt: list of number of averages per bin
