@@ -22,9 +22,9 @@ def get_build_info():
     ----------
     """
 
-    return {"version": "0.5.1",
-            "date":    "07/10/2021-13:58:39",
-            "hash":    "0x0AE2580C",
+    return {"version": "0.5.2",
+            "date":    "11/10/2021-15:51:27",
+            "hash":    "0xF668D53D",
             "dirty":   False}
 
 
